@@ -31,13 +31,17 @@
 #include <gtkmm/icontheme.h>
 #include <gtkmm/statusicon.h>
 
+#include "base/macros.hpp"
 #include "actionmanager.hpp"
 #include "ignote.hpp"
-#include "keybinder.hpp"
 #include "remotecontrolproxy.hpp"
 #include "tray.hpp"
 #include "synchronization/syncdialog.hpp"
 
+#ifdef HAVE_X11_SUPPORT
+#include "keybinder.hpp"
+#endif
+
 namespace gnote {
 
 class PreferencesDialog;
@@ -113,10 +117,12 @@ public:
     {
       return *m_manager;
     }
+#ifdef HAVE_X11_SUPPORT
   IKeybinder & keybinder()
     {
       return *m_keybinder;
     }
+#endif
 
   void setup_global_actions();
   void start_tray_icon();
@@ -126,10 +132,10 @@ public:
   void on_show_preferences_action(const Glib::VariantBase&);
   void on_show_help_action(const Glib::VariantBase&);
   void on_show_about_action(const Glib::VariantBase&);
-  virtual MainWindow & new_main_window();
-  virtual MainWindow & get_main_window();
-  virtual MainWindow & get_window_for_note();
-  virtual void open_search_all();
+  virtual MainWindow & new_main_window() override;
+  virtual MainWindow & get_main_window() override;
+  virtual MainWindow & get_window_for_note() override;
+  virtual void open_search_all() override;
   void open_note_sync_window(const Glib::VariantBase&);
 
   bool tray_icon_showing()
@@ -149,11 +155,11 @@ public:
       m_tray = tray;
     }
   static void register_remote_control(NoteManager & manager, RemoteControlProxy::slot_name_acquire_finish on_finish);
-  virtual void open_note(const Note::Ptr & note);
+  virtual void open_note(const Note::Ptr & note) override;
 protected:
-  virtual int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine> & command_line);
-  virtual void on_startup();
-  virtual void on_window_removed(Gtk::Window *window);
+  virtual int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine> & command_line) override;
+  virtual void on_startup() override;
+  virtual void on_window_removed(Gtk::Window *window) override;
 private:
   Gnote();
   std::string get_note_path(const std::string & override_path);
@@ -172,7 +178,6 @@ private:
   void register_object();
 
   NoteManager *m_manager;
-  IKeybinder  *m_keybinder;
   Glib::RefPtr<Gtk::IconTheme> m_icon_theme;
   Glib::RefPtr<TrayIcon> m_tray_icon;
   Tray::Ptr m_tray;
@@ -180,6 +185,9 @@ private:
   PreferencesDialog *m_prefsdlg;
   GnoteCommandLine cmd_line;
   sync::SyncDialog::Ptr m_sync_dlg;
+#ifdef HAVE_X11_SUPPORT
+  IKeybinder  *m_keybinder;
+#endif
 };
 
 
