@@ -37,6 +37,7 @@
 #include <gtkmm/button.h>
 #include <gtkmm/stock.h>
 
+#include "mainwindow.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
 #include "noterenamedialog.hpp"
@@ -123,6 +124,29 @@ namespace gnote {
       dialog.run();
     }
 
+    void place_cursor_and_selection(const NoteData & data, const Glib::RefPtr<NoteBuffer> & buffer)
+    {
+      Gtk::TextIter cursor;
+      bool select = false;
+      if(data.cursor_position() >= 0) {
+        // Move cursor to last-saved position
+        cursor = buffer->get_iter_at_offset(data.cursor_position());
+        select = true;
+      } 
+      else {
+        // Avoid title line
+        cursor = buffer->get_iter_at_line(2);
+      }
+      buffer->place_cursor(cursor);
+
+      if(select && data.selection_bound_position() >= 0) {
+        // Move selection bound to last-saved position
+        Gtk::TextIter selection_bound;
+        selection_bound = buffer->get_iter_at_offset(data.selection_bound_position());
+        buffer->move_mark(buffer->get_selection_bound(), selection_bound);
+      }
+    }
+
   }
 
 
@@ -130,34 +154,23 @@ namespace gnote {
 
   NoteData::NoteData(const std::string & _uri)
     : m_uri(_uri)
-    , m_cursor_pos(0)
+    , m_cursor_pos(s_noPosition)
     , m_selection_bound_pos(s_noPosition)
     , m_width(0)
     , m_height(0)
-    , m_x(s_noPosition)
-    , m_y(s_noPosition)
   {
   }
 
 
-  void NoteData::set_position_extent(int _x, int _y, int _width, int _height)
+  void NoteData::set_extent(int _width, int _height)
   {
-    if (_x < 0 || _y < 0)
-      return;
     if (_width <= 0 || _height <= 0)
       return;
 
-    m_x = _x;
-    m_y = _y;
     m_width = _width;
     m_height = _height;
   }
 
-  bool NoteData::has_position()
-  {
-    return (m_x != s_noPosition) && (m_y != s_noPosition);
-  }
-
   bool NoteData::has_extent()
   {
     return (m_width != 0) && (m_height != 0);
@@ -225,23 +238,7 @@ namespace gnote {
                                        m_data->text());
       m_buffer->set_modified(false);
 
-      Gtk::TextIter cursor;
-      if (m_data->cursor_position() != 0) {
-        // Move cursor to last-saved position
-        cursor = m_buffer->get_iter_at_offset (m_data->cursor_position());
-      } 
-      else {
-        // Avoid title line
-        cursor = m_buffer->get_iter_at_line(2);
-      }
-      m_buffer->place_cursor(cursor);
-
-      if(m_data->selection_bound_position() >= 0) {
-        // Move selection bound to last-saved position
-        Gtk::TextIter selection_bound;
-        selection_bound = m_buffer->get_iter_at_offset(m_data->selection_bound_position());
-        m_buffer->move_mark(m_buffer->get_selection_bound(), selection_bound);
-      }
+      place_cursor_and_selection(*m_data, m_buffer);
 
       // New events should create Undo actions
       m_buffer->undoer().thaw_undo ();
@@ -378,7 +375,12 @@ namespace gnote {
 
     if (m_window) {
       if(m_window->host()) {
+        MainWindow *win = dynamic_cast<MainWindow*>(m_window->host());
+        bool close_host = win ? win->close_on_escape() : false;
         m_window->host()->unembed_widget(*m_window);
+        if(close_host) {
+          win->close_window();
+        }
       }
       delete m_window; 
       m_window = NULL;
@@ -452,11 +454,13 @@ namespace gnote {
   void Note::on_buffer_mark_set(const Gtk::TextBuffer::iterator & iter,
                                 const Glib::RefPtr<Gtk::TextBuffer::Mark> & insert)
   {
-    if(insert == m_buffer->get_insert()) {
-      m_data.data().set_cursor_position(iter.get_offset());
+    Gtk::TextIter start, end;
+    if(m_buffer->get_selection_bounds(start, end)) {
+      m_data.data().set_cursor_position(start.get_offset());
+      m_data.data().set_selection_bound_position(end.get_offset());
     }
-    else if(insert == m_buffer->get_selection_bound()) {
-      m_data.data().set_selection_bound_position(iter.get_offset());
+    else if(insert->get_name() == "insert") {
+      m_data.data().set_cursor_position(iter.get_offset());
     }
     else {
       return;
@@ -997,9 +1001,9 @@ namespace gnote {
         sigc::mem_fun(*this, &Note::on_buffer_tag_applied));
       m_buffer->signal_remove_tag().connect(
         sigc::mem_fun(*this, &Note::on_buffer_tag_removed));
-      m_buffer->signal_mark_set().connect(
+      m_mark_set_conn = m_buffer->signal_mark_set().connect(
         sigc::mem_fun(*this, &Note::on_buffer_mark_set));
-      m_buffer->signal_mark_deleted().connect(
+      m_mark_deleted_conn = m_buffer->signal_mark_deleted().connect(
         sigc::mem_fun(*this, &Note::on_buffer_mark_deleted));
     }
     return m_buffer;
@@ -1017,11 +1021,9 @@ namespace gnote {
       if(m_data.data().has_extent()) {
         m_window->set_size(m_data.data().width(), m_data.data().height());
       }
-      if(m_data.data().has_position()) {
-        m_window->set_position(m_data.data().x(), m_data.data().y());
-      }
 
       m_window->signal_embedded.connect(sigc::mem_fun(*this, &Note::on_note_window_embedded));
+      m_window->signal_foregrounded.connect(sigc::mem_fun(*this, &Note::on_note_window_foregrounded));
     }
     return m_window;
   }
@@ -1042,6 +1044,17 @@ namespace gnote {
     notebooks::NotebookManager::obj().active_notes_notebook()->add_note(shared_from_this());
   }
 
+  void Note::on_note_window_foregrounded()
+  {
+    m_mark_set_conn.block();
+    m_mark_deleted_conn.block();
+
+    place_cursor_and_selection(m_data.data(), m_buffer);
+
+    m_mark_set_conn.unblock();
+    m_mark_deleted_conn.unblock();
+  }
+
   bool Note::is_special() const
   { 
     return (m_manager.start_note_uri() == m_data.data().uri());
@@ -1198,12 +1211,6 @@ namespace gnote {
         else if(name == "height") {
           note->height() = boost::lexical_cast<int>(xml.read_string());
         }
-        else if(name == "x") {
-          note->x() = boost::lexical_cast<int>(xml.read_string());
-        }
-        else if(name == "y") {
-          note->y() = boost::lexical_cast<int>(xml.read_string());
-        }
         else if(name == "tags") {
           xmlDocPtr doc2 = xmlParseDoc((const xmlChar*)xml.read_outer_xml().c_str());
 
@@ -1343,14 +1350,6 @@ namespace gnote {
     xml.write_string(boost::lexical_cast<std::string>(note.height()));
     xml.write_end_element();
 
-    xml.write_start_element("", "x", "");
-    xml.write_string (boost::lexical_cast<std::string>(note.x()));
-    xml.write_end_element();
-
-    xml.write_start_element ("", "y", "");
-    xml.write_string (boost::lexical_cast<std::string>(note.y()));
-    xml.write_end_element();
-
     if (note.tags().size() > 0) {
       xml.write_start_element ("", "tags", "");
       for(NoteData::TagMap::const_iterator iter = note.tags().begin();
