@@ -137,22 +137,6 @@ public:
     {
       return m_height;
     }
-  int x() const
-    {
-      return m_x;
-    }
-  int & x()
-    {
-      return m_x;
-    }
-  int y() const
-    {
-      return m_y;
-    }
-  int & y()
-    {
-      return m_y;
-    }
   const TagMap & tags() const
     {
       return m_tags;
@@ -162,8 +146,7 @@ public:
       return m_tags;
     }
 
-  void set_position_extent(int x, int y, int width, int height);
-  bool has_position();
+  void set_extent(int width, int height);
   bool has_extent();
 
 private:
@@ -176,7 +159,6 @@ private:
   int               m_cursor_pos;
   int               m_selection_bound_pos;
   int               m_width, m_height;
-  int               m_x, m_y;
 
   TagMap m_tags;
 };
@@ -375,6 +357,7 @@ private:
   void remove_links(const std::string & old_title,
                     const Ptr & renamed);
   void on_note_window_embedded();
+  void on_note_window_foregrounded();
 
   Note(NoteData * data, const std::string & filepath, NoteManager & manager);
 
@@ -412,6 +395,9 @@ private:
   TagAddedHandler    m_signal_tag_added;
   TagRemovingHandler m_signal_tag_removing;
   TagRemovedHandler  m_signal_tag_removed;
+
+  sigc::connection m_mark_set_conn;
+  sigc::connection m_mark_deleted_conn;
 };
 
 class NoteArchiver
