@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011 Aurimas Cernius
+ * Copyright (C) 2011,2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -130,7 +130,7 @@ namespace gnote {
   void NoteTag::get_extents(const Gtk::TextIter & iter, Gtk::TextIter & start,
                             Gtk::TextIter & end)
   {
-    Glib::RefPtr<Gtk::TextTag> this_ref(this);
+    Glib::RefPtr<Gtk::TextTag> this_ref = NoteTagTable::instance()->lookup(property_name());
     start = iter;
     if (!start.begins_tag (this_ref)) {
       start.backward_to_tag_toggle (this_ref);
@@ -255,7 +255,7 @@ namespace gnote {
       }
     }
 #endif
-    retval = m_signal_activate(NoteTag::Ptr(this), editor, start, end);
+    retval = m_signal_activate(editor, start, end);
 
     return retval;
   }
@@ -290,7 +290,7 @@ namespace gnote {
     m_widget = value;
 
     try {
-      m_signal_changed(Glib::RefPtr<Gtk::TextTag>(this), false);
+      m_signal_changed(*this, false);
     } catch (sharp::Exception & e) {
       DBG_OUT("Exception calling TagChanged from NoteTag.set_Widget: %s", e.what());
     }
@@ -417,7 +417,6 @@ namespace gnote {
     add (tag);
 
     tag = NoteTag::create("note-title", 0);
-    tag->property_underline() = Pango::UNDERLINE_SINGLE;
     tag->set_palette_foreground(CONTRAST_COLOR_BLUE);
     tag->property_scale() = Pango::SCALE_XX_LARGE;
     // FiXME: Hack around extra rewrite on open
