@@ -32,7 +32,6 @@
 
 #include "debug.hpp"
 #include "ignote.hpp"
-#include "iconmanager.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
@@ -52,14 +51,17 @@ namespace gnote {
     , m_window_menu_embedded(NULL)
     , m_window_menu_default(NULL)
     , m_keybinder(get_accel_group())
+    , m_open_notes_in_new_window(Preferences::obj().get_schema_settings(
+        Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW))
   {
     set_default_size(450,400);
     set_resizable(true);
     set_hide_titlebar_when_maximized(true);
-    if(Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
-         Preferences::MAIN_WINDOW_MAXIMIZED)) {
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+    if(settings->get_boolean(Preferences::MAIN_WINDOW_MAXIMIZED)) {
       maximize();
     }
+    settings->signal_changed().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_settings_changed));
 
     set_has_resize_grip(true);
 
@@ -84,8 +86,8 @@ namespace gnote {
     signal_key_press_event()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_key_pressed));
     IGnote::obj().signal_quit
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_close_window));// to save size/pos
-    m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::on_close_window),
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::close_window));// to save size/pos
+    m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_window),
                                 GDK_KEY_W, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
 
     m_window_menu_default = make_window_menu(m_window_actions_button, std::vector<Gtk::MenuItem*>());
@@ -131,11 +133,13 @@ namespace gnote {
     left_box->get_style_context()->add_class(GTK_STYLE_CLASS_RAISED);
     left_box->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
     m_all_notes_button = manage(new Gtk::Button);
-    Gtk::Image *image = manage(new Gtk::Image(IconManager::obj().get_icon("go-previous-symbolic", icon_size)));
+    Gtk::Image *image = manage(new Gtk::Image);
+    image->property_icon_name() = "go-previous-symbolic";
+    image->property_icon_size() = GTK_ICON_SIZE_MENU;
     image->property_margin() = icon_margin;
     m_all_notes_button->set_image(*image);
     m_all_notes_button->set_tooltip_text(_("All Notes"));
-    m_all_notes_button->signal_clicked().connect(sigc::mem_fun(*this, &NoteRecentChanges::present_search));
+    m_all_notes_button->signal_clicked().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_all_notes_button_clicked));
     m_all_notes_button->show_all();
     left_box->attach(*m_all_notes_button, 0, 0, 1, 1);
 
@@ -158,7 +162,9 @@ namespace gnote {
     Gtk::Grid *right_box = manage(new Gtk::Grid);
     right_box->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
     right_box->set_column_spacing(5);
-    image = manage(new Gtk::Image(IconManager::obj().get_icon("edit-find-symbolic", icon_size)));
+    image = manage(new Gtk::Image);
+    image->property_icon_name() = "edit-find-symbolic";
+    image->property_icon_size() = GTK_ICON_SIZE_MENU;
     image->property_margin() = icon_margin;
     m_search_button.set_image(*image);
     m_search_button.signal_toggled().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_search_button_toggled));
@@ -168,7 +174,9 @@ namespace gnote {
     right_box->attach(m_search_button, 0, 0, 1, 1);
 
     m_window_actions_button = manage(new Gtk::Button);
-    image = manage(new Gtk::Image(IconManager::obj().get_icon("emblem-system-symbolic", icon_size)));
+    image = manage(new Gtk::Image);
+    image->property_icon_name() = "emblem-system-symbolic";
+    image->property_icon_size() = GTK_ICON_SIZE_MENU;
     image->property_margin() = icon_margin;
     m_window_actions_button->set_image(*image);
     m_window_actions_button->signal_clicked().connect(
@@ -306,7 +314,12 @@ namespace gnote {
 
   void NoteRecentChanges::on_open_note(const Note::Ptr & note)
   {
-    present_note(note);
+    if(m_open_notes_in_new_window) {
+      on_open_note_new_window(note);
+    }
+    else {
+      present_note(note);
+    }
   }
 
   void NoteRecentChanges::on_open_note_new_window(const Note::Ptr & note)
@@ -314,6 +327,7 @@ namespace gnote {
     MainWindow & window = IGnote::obj().new_main_window();
     window.present();
     window.present_note(note);
+    window.close_on_escape(true);
   }
 
   void NoteRecentChanges::on_delete_note()
@@ -323,11 +337,15 @@ namespace gnote {
 
 
 
-  void NoteRecentChanges::on_close_window()
+  void NoteRecentChanges::close_window()
   {
-    Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_boolean(
-        Preferences::MAIN_WINDOW_MAXIMIZED,
-        get_window()->get_state() & Gdk::WINDOW_STATE_MAXIMIZED);
+    Glib::RefPtr<Gdk::Window> win = get_window();
+    // background window (for tray to work) might not have GDK window
+    if(win) {
+      Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_boolean(
+          Preferences::MAIN_WINDOW_MAXIMIZED,
+          win->get_state() & Gdk::WINDOW_STATE_MAXIMIZED);
+    }
     std::vector<Gtk::Widget*> current = m_embed_box.get_children();
     for(std::vector<Gtk::Widget*>::iterator iter = current.begin();
         iter != current.end(); ++iter) {
@@ -343,7 +361,7 @@ namespace gnote {
 
   bool NoteRecentChanges::on_delete(GdkEventAny *)
   {
-    on_close_window();
+    close_window();
     return true;
   }
 
@@ -356,8 +374,9 @@ namespace gnote {
         m_search_button.set_active(false);
       }
       // Allow Escape to close the window
-      else if(&m_search_notes_widget == dynamic_cast<SearchNotesWidget*>(currently_embedded())) {
-        on_close_window();
+      else if(close_on_escape()
+              || &m_search_notes_widget == dynamic_cast<SearchNotesWidget*>(currently_embedded())) {
+        close_window();
       }
       else {
         EmbeddableWidget *current_item = currently_embedded();
@@ -441,7 +460,7 @@ namespace gnote {
 	foreground_embedded(**m_embedded_widgets.rbegin());
       }
       else if(get_visible()) {
-        on_close_window();
+        close_window();
       }
     }
   }
@@ -545,7 +564,7 @@ namespace gnote {
   {
     std::string title;
     if(name != "") {
-      title = "[" + name + "] - ";
+      title = name + " - ";
     }
     title += _("Notes");
     set_title(title);
@@ -641,6 +660,12 @@ namespace gnote {
     }
   }
 
+  void NoteRecentChanges::on_all_notes_button_clicked()
+  {
+    close_on_escape(false);  // intentional switch to search, user probably want to work more with this window
+    present_search();
+  }
+
   void NoteRecentChanges::on_show_window_menu()
   {
     HasActions *embed_with_actions = dynamic_cast<HasActions*>(currently_embedded());
@@ -663,7 +688,7 @@ namespace gnote {
     }
     Gtk::MenuItem *item = manage(new Gtk::MenuItem(_("_Close"), true));
     item->add_accelerator("activate", get_accel_group(), GDK_KEY_W, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
-    item->signal_activate().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_close_window));
+    item->signal_activate().connect(sigc::mem_fun(*this, &NoteRecentChanges::close_window));
     menu->append(*item);
     menu->property_attach_widget() = button;
     menu->show_all();
@@ -697,5 +722,13 @@ namespace gnote {
     }
   }
 
+  void NoteRecentChanges::on_settings_changed(const Glib::ustring & key)
+  {
+    if(key == Preferences::OPEN_NOTES_IN_NEW_WINDOW) {
+      m_open_notes_in_new_window = Preferences::obj().get_schema_settings(
+        Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
+    }
+  }
+
 }
 
