@@ -30,6 +30,7 @@
 #include <gtkmm/applicationwindow.h>
 #include <gtkmm/grid.h>
 
+#include "base/macros.hpp"
 #include "note.hpp"
 #include "searchnoteswidget.hpp"
 #include "utils.hpp"
@@ -43,28 +44,28 @@ class NoteRecentChanges
 public:
   NoteRecentChanges(NoteManager& m);
   virtual ~NoteRecentChanges();
-  virtual void show_search_bar();
-  virtual void set_search_text(const std::string & value);
-  virtual void present_note(const Note::Ptr & note);
-  virtual void new_note();
-  virtual void present_search();
+  virtual void show_search_bar() override;
+  virtual void set_search_text(const std::string & value) override;
+  virtual void present_note(const Note::Ptr & note) override;
+  virtual void new_note() override;
+  virtual void present_search() override;
+  virtual void close_window() override;
 
-  virtual void embed_widget(EmbeddableWidget &);
-  virtual void unembed_widget(EmbeddableWidget &);
-  virtual void foreground_embedded(EmbeddableWidget &);
-  virtual void background_embedded(EmbeddableWidget &);
+  virtual void embed_widget(EmbeddableWidget &) override;
+  virtual void unembed_widget(EmbeddableWidget &) override;
+  virtual void foreground_embedded(EmbeddableWidget &) override;
+  virtual void background_embedded(EmbeddableWidget &) override;
   virtual bool running()
     {
       return m_mapped;
     }
 protected:
-  virtual void on_show();
-  virtual bool on_map_event(GdkEventAny *evt);
+  virtual void on_show() override;
+  virtual bool on_map_event(GdkEventAny *evt) override;
 private:
   void on_open_note(const Note::Ptr &);
   void on_open_note_new_window(const Note::Ptr &);
   void on_delete_note();
-  void on_close_window();
   bool on_delete(GdkEventAny *);
   bool on_key_pressed(GdkEventKey *);
   bool is_foreground(EmbeddableWidget &);
@@ -77,6 +78,7 @@ private:
   void entry_changed_timeout();
   std::string get_search_text();
   void update_toolbar(EmbeddableWidget & widget);
+  void on_all_notes_button_clicked();
   void on_show_window_menu();
   void on_search_button_toggled();
   void on_find_next_button_clicked();
@@ -85,6 +87,7 @@ private:
   std::vector<Gtk::MenuItem*> & make_menu_items(std::vector<Gtk::MenuItem*> & items,
                                                 const std::vector<Glib::RefPtr<Gtk::Action> > & actions);
   void on_main_window_actions_changed(Gtk::Menu **menu);
+  void on_settings_changed(const Glib::ustring & key);
 
   NoteManager        &m_note_manager;
   SearchNotesWidget   m_search_notes_widget;
@@ -106,6 +109,7 @@ private:
   Gtk::Menu          *m_window_menu_embedded;
   Gtk::Menu          *m_window_menu_default;
   utils::GlobalKeybinder m_keybinder;
+  bool                m_open_notes_in_new_window;
 };
 
 
