@@ -59,6 +59,8 @@ SearchNotesWidget::SearchNotesWidget(NoteManager & m)
   , m_note_list_context_menu(NULL)
   , m_notebook_list_context_menu(NULL)
   , m_initial_position_restored(false)
+  , m_sort_column_id(2)
+  , m_sort_column_order(Gtk::SORT_DESCENDING)
 {
   set_hexpand(true);
   set_vexpand(true);
@@ -100,6 +102,12 @@ SearchNotesWidget::SearchNotesWidget(NoteManager & m)
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_removed_from_notebook));
   notebooks::NotebookManager::obj().signal_note_pin_status_changed
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_pin_status_changed));
+
+  Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+  settings->signal_changed().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_settings_changed));
+  parse_sorting_setting(settings->get_string(Preferences::SEARCH_SORTING));
+  settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE);
+  settings->signal_changed().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_settings_changed));
 }
 
 SearchNotesWidget::~SearchNotesWidget()
@@ -134,8 +142,11 @@ void SearchNotesWidget::make_actions()
   m_delete_note_action = Gtk::Action::create("DeleteNoteAction", _("_Delete"));
   m_delete_note_action->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::delete_selected_notes));
 
-  m_delete_notebook_action = Gtk::Action::create("DeleteNotebookAction", _("_Delete Notebook"));
+  m_delete_notebook_action = Gtk::Action::create("DeleteNotebookAction", _("_Delete"));
   m_delete_notebook_action->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_delete_notebook));
+
+  m_rename_notebook_action = Gtk::Action::create("RenameNotebookAction", _("Re_name..."));
+  m_rename_notebook_action->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_rename_notebook));
 }
 
 void SearchNotesWidget::perform_search(const std::string & search_text)
@@ -253,8 +264,6 @@ Gtk::Widget *SearchNotesWidget::make_notebooks_pane()
 
 void SearchNotesWidget::save_position()
 {
-  int x;
-  int y;
   int width;
   int height;
 
@@ -272,11 +281,8 @@ void SearchNotesWidget::save_position()
     return;
   }
 
-  window->get_position(x, y);
   window->get_size(width, height);
 
-  settings->set_int(Preferences::SEARCH_WINDOW_X_POS, x);
-  settings->set_int(Preferences::SEARCH_WINDOW_Y_POS, y);
   settings->set_int(Preferences::SEARCH_WINDOW_WIDTH, width);
   settings->set_int(Preferences::SEARCH_WINDOW_HEIGHT, height);
 }
@@ -342,6 +348,7 @@ void SearchNotesWidget::on_notebook_row_edited(const Glib::ustring& /*tree_path*
   Gtk::TreeIter iter;
   if(notebooks::NotebookManager::obj().get_notebook_iter(new_notebook, iter)) {
     m_notebooksTree->get_selection()->select(iter);
+    m_notebooksTree->set_cursor(m_notebooksTree->get_model()->get_path(iter));
   }
 }
 
@@ -366,6 +373,7 @@ void SearchNotesWidget::on_notebook_selection_changed()
     m_on_notebook_selection_changed_cid.block();
     select_all_notes_notebook();
     m_delete_notebook_action->set_sensitive(false);
+    m_rename_notebook_action->set_sensitive(false);
     m_on_notebook_selection_changed_cid.unblock();
   }
   else {
@@ -376,9 +384,11 @@ void SearchNotesWidget::on_notebook_selection_changed()
     bool allow_edit = false;
     if(std::tr1::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
       m_delete_notebook_action->set_sensitive(false);
+      m_rename_notebook_action->set_sensitive(false);
     }
     else {
       m_delete_notebook_action->set_sensitive(true);
+      m_rename_notebook_action->set_sensitive(true);
       allow_edit = true;
     }
 
@@ -420,6 +430,9 @@ bool SearchNotesWidget::on_notebooks_tree_button_pressed(GdkEventButton *ev)
 bool SearchNotesWidget::on_notebooks_key_pressed(GdkEventKey *ev)
 {
   switch(ev->keyval) {
+  case GDK_KEY_F2:
+    on_rename_notebook();
+    break;
   case GDK_KEY_Menu:
   {
     Gtk::Menu *menu = get_notebook_list_context_menu();
@@ -488,6 +501,10 @@ void SearchNotesWidget::update_results()
                               sigc::mem_fun(*this, &SearchNotesWidget::compare_titles));
   m_store_sort->set_sort_func(2 /* change date */,
                               sigc::mem_fun(*this, &SearchNotesWidget::compare_dates));
+  m_store_sort->set_sort_column(m_sort_column_id, m_sort_column_order);
+  m_store_sort->unset_default_sort_func();
+  m_store_sort->signal_sort_column_changed()
+    .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_sorting_changed));
 
   int cnt = 0;
 
@@ -508,7 +525,7 @@ void SearchNotesWidget::update_results()
 
   perform_search();
 
-  if(sort_column >= 0) {
+  if(sort_column >= 0 && m_no_matches_box && get_child2() != m_no_matches_box) {
     // Set the sort column after loading data, since we
     // don't want to resort on every append.
     m_store_sort->set_sort_column(sort_column, sort_type);
@@ -660,7 +677,7 @@ void SearchNotesWidget::make_recent_tree()
   m_tree->append_column(*title);
 
   Gtk::TreeViewColumn *change = manage(new Gtk::TreeViewColumn());
-  change->set_title(_("Last Changed"));
+  change->set_title(_("Modified"));
   change->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
   change->set_resizable(false);
 
@@ -985,14 +1002,12 @@ void SearchNotesWidget::on_treeview_drag_data_get(const Glib::RefPtr<Gdk::DragCo
 
 void SearchNotesWidget::remove_matches_column()
 {
-  if(m_matches_column == NULL) {
+  if(m_matches_column == NULL || !m_matches_column->get_visible()) {
     return;
   }
 
-  m_tree->remove_column(*m_matches_column);
-  m_matches_column = NULL;
-
-  m_store_sort->set_sort_column(2, Gtk::SORT_DESCENDING);
+  m_matches_column->set_visible(false);
+  m_store_sort->set_sort_column(m_sort_column_id, m_sort_column_order);
 }
 
 // called when no search results are found in the selected notebook
@@ -1003,7 +1018,7 @@ void SearchNotesWidget::no_matches_found_action()
     Glib::ustring message = _("No results found in the selected notebook.\nClick here to search across all notes.");
     Gtk::LinkButton *link_button = manage(new Gtk::LinkButton("", message));
     link_button->signal_activate_link()
-      .connect(sigc::mem_fun(*this, &SearchNotesWidget::show_all_search_results));
+      .connect(sigc::mem_fun(*this, &SearchNotesWidget::show_all_search_results), false);
     link_button->set_tooltip_text(_("Click here to search across all notebooks"));
     link_button->show();
     Gtk::Alignment *no_matches_found = manage(new Gtk::Alignment(Gtk::ALIGN_CENTER, Gtk::ALIGN_CENTER, 0.0, 0.0));
@@ -1046,12 +1061,16 @@ void SearchNotesWidget::add_matches_column()
     m_tree->append_column(*m_matches_column);
     m_store_sort->set_sort_column(4, Gtk::SORT_DESCENDING);
   }
+  else {
+    m_matches_column->set_visible(true);
+    m_store_sort->set_sort_column(4, Gtk::SORT_DESCENDING);
+  }
 }
 
 bool SearchNotesWidget::show_all_search_results()
 {
   select_all_notes_notebook();
-  return false;
+  return true;
 }
 
 void SearchNotesWidget::matches_column_data_func(Gtk::CellRenderer * cell,
@@ -1267,11 +1286,16 @@ Gtk::Menu *SearchNotesWidget::get_note_list_context_menu()
 {
   if(!m_note_list_context_menu) {
     m_note_list_context_menu = new Gtk::Menu;
+    bool open_notes_in_new_window = Preferences::obj().get_schema_settings(
+      Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
 
-    Gtk::MenuItem *item = manage(new Gtk::MenuItem);
-    item->set_related_action(m_open_note_action);
-    item->add_accelerator("activate", m_accel_group, GDK_KEY_O, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
-    m_note_list_context_menu->add(*item);
+    Gtk::MenuItem *item;
+    if(!open_notes_in_new_window) {
+      item = manage(new Gtk::MenuItem);
+      item->set_related_action(m_open_note_action);
+      item->add_accelerator("activate", m_accel_group, GDK_KEY_O, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+      m_note_list_context_menu->add(*item);
+    }
 
     item = manage(new Gtk::MenuItem);
     item->set_related_action(m_open_note_new_window_action);
@@ -1283,7 +1307,7 @@ Gtk::Menu *SearchNotesWidget::get_note_list_context_menu()
     m_note_list_context_menu->add(*item);
 
     m_note_list_context_menu->add(*manage(new Gtk::SeparatorMenuItem));
-    item = manage(new Gtk::MenuItem(_("_New Note"), true));
+    item = manage(new Gtk::MenuItem(_("_New"), true));
     item->add_accelerator("activate", m_accel_group, GDK_KEY_N, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     item->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::new_note));
     m_note_list_context_menu->add(*item);
@@ -1317,10 +1341,13 @@ Gtk::Menu *SearchNotesWidget::get_notebook_list_context_menu()
       .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_open_notebook_template_note));
     m_notebook_list_context_menu->add(*item);
     item = manage(new Gtk::MenuItem);
+    item->set_related_action(m_rename_notebook_action);
+    m_notebook_list_context_menu->add(*item);
+    item = manage(new Gtk::MenuItem);
     item->set_related_action(m_delete_notebook_action);
     m_notebook_list_context_menu->add(*item);
     m_notebook_list_context_menu->add(*manage(new Gtk::SeparatorMenuItem));
-    item = manage(new Gtk::MenuItem(_("_New Notebook"), true));
+    item = manage(new Gtk::MenuItem(_("_New..."), true));
     item->signal_activate()
       .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_new_notebook));
     m_notebook_list_context_menu->add(*item);
@@ -1365,6 +1392,7 @@ void SearchNotesWidget::foreground()
   Gtk::Window *win = dynamic_cast<Gtk::Window*>(host());
   if(win) {
     win->add_accel_group(m_accel_group);
+    win->set_focus(*m_tree);
   }
 }
 
@@ -1378,14 +1406,6 @@ void SearchNotesWidget::background()
   }
 }
 
-void SearchNotesWidget::hint_position(int & x, int & y)
-{
-  Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
-    .get_schema_settings(Preferences::SCHEMA_GNOTE);
-  x = settings->get_int(Preferences::SEARCH_WINDOW_X_POS);
-  y = settings->get_int(Preferences::SEARCH_WINDOW_Y_POS);
-}
-
 void SearchNotesWidget::hint_size(int & width, int & height)
 {
   Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
@@ -1414,4 +1434,99 @@ sigc::signal<void> & SearchNotesWidget::signal_actions_changed()
   return IActionManager::obj().signal_main_window_search_actions_changed;
 }
 
+void SearchNotesWidget::on_settings_changed(const Glib::ustring & key)
+{
+  if(key == Preferences::OPEN_NOTES_IN_NEW_WINDOW) {
+    if(m_note_list_context_menu) {
+      delete m_note_list_context_menu;
+      m_note_list_context_menu = NULL;
+    }
+  }
+  else if(key == Preferences::DESKTOP_GNOME_CLOCK_FORMAT) {
+    update_results();
+  }
+}
+
+void SearchNotesWidget::on_sorting_changed()
+{
+  // don't do anything if in search mode
+  if(m_matches_column && m_matches_column->get_visible()) {
+    return;
+  }
+
+  if(m_store_sort) {
+    m_store_sort->get_sort_column_id(m_sort_column_id, m_sort_column_order);
+    Glib::ustring value;
+    switch(m_sort_column_id) {
+    case 1:
+      value = "note:";
+      break;
+    case 2:
+      value = "change:";
+      break;
+    default:
+      return;
+    }
+    if(m_sort_column_order == Gtk::SORT_ASCENDING) {
+      value += "asc";
+    }
+    else {
+      value += "desc";
+    }
+    Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
+      Preferences::SEARCH_SORTING, value);
+  }
+}
+
+void SearchNotesWidget::parse_sorting_setting(const Glib::ustring & sorting)
+{
+  std::vector<std::string> tokens;
+  sharp::string_split(tokens, sorting.lowercase(), ":");
+  if(tokens.size() != 2) {
+    ERR_OUT(_("Failed to parse setting %s (Value: %s):"), Preferences::SEARCH_SORTING, sorting.c_str());
+    ERR_OUT(_("Expected format 'column:order'"));
+    return;
+  }
+  int column_id;
+  Gtk::SortType order;
+  if(tokens[0] == "note") {
+    column_id = 1;
+  }
+  else if(tokens[0] == "change") {
+    column_id = 2;
+  }
+  else {
+    ERR_OUT(_("Failed to parse setting %s (Value: %s):"), Preferences::SEARCH_SORTING, sorting.c_str());
+    ERR_OUT(_("Unrecognized column %s"), tokens[0].c_str());
+    return;
+  }
+  if(tokens[1] == "asc") {
+    order = Gtk::SORT_ASCENDING;
+  }
+  else if(tokens[1] == "desc") {
+    order = Gtk::SORT_DESCENDING;
+  }
+  else {
+    ERR_OUT(_("Failed to parse setting %s (Value: %s):"), Preferences::SEARCH_SORTING, sorting.c_str());
+    ERR_OUT(_("Unrecognized order %s"), tokens[1].c_str());
+    return;
+  }
+
+  m_sort_column_id = column_id;
+  m_sort_column_order = order;
+}
+
+void SearchNotesWidget::on_rename_notebook()
+{
+  Glib::RefPtr<Gtk::TreeSelection> selection = m_notebooksTree->get_selection();
+  if(selection == 0) {
+    return;
+  }
+  std::vector<Gtk::TreeModel::Path> selected_row = selection->get_selected_rows();
+  if(selected_row.size() != 1) {
+    return;
+  }
+  m_notebooksTree->set_cursor(selected_row[0], *m_notebooksTree->get_column(0), true);
+}
+
 }
