@@ -31,6 +31,7 @@
 #include <gtkmm/scrolledwindow.h>
 #include <sigc++/sigc++.h>
 
+#include "base/macros.hpp"
 #include "mainwindowembeds.hpp"
 #include "notebooks/notebook.hpp"
 #include "notebooks/notebookstreeview.hpp"
@@ -47,15 +48,14 @@ class SearchNotesWidget
 public:
   SearchNotesWidget(NoteManager & m);
   virtual ~SearchNotesWidget();
-  virtual std::string get_name() const;
-  virtual void foreground();
-  virtual void background();
-  virtual void hint_position(int & x, int & y);
-  virtual void hint_size(int & width, int & height);
-  virtual void size_internals();
-  virtual void perform_search(const std::string & search_text);
-  virtual std::vector<Glib::RefPtr<Gtk::Action> > get_widget_actions();
-  virtual sigc::signal<void> & signal_actions_changed();
+  virtual std::string get_name() const override;
+  virtual void foreground() override;
+  virtual void background() override;
+  virtual void hint_size(int & width, int & height) override;
+  virtual void size_internals() override;
+  virtual void perform_search(const std::string & search_text) override;
+  virtual std::vector<Glib::RefPtr<Gtk::Action> > get_widget_actions() override;
+  virtual sigc::signal<void> & signal_actions_changed() override;
 
   void select_all_notes_notebook();
   void new_note();
@@ -121,6 +121,10 @@ private:
   void on_open_notebook_template_note();
   void on_new_notebook();
   void on_delete_notebook();
+  void on_settings_changed(const Glib::ustring & key);
+  void on_sorting_changed();
+  void parse_sorting_setting(const Glib::ustring & sorting);
+  void on_rename_notebook();
 
   class RecentSearchColumnTypes
     : public Gtk::TreeModelColumnRecord
@@ -152,6 +156,7 @@ private:
   Glib::RefPtr<Gtk::Action> m_open_note_new_window_action;
   Glib::RefPtr<Gtk::Action> m_delete_note_action;
   Glib::RefPtr<Gtk::Action> m_delete_notebook_action;
+  Glib::RefPtr<Gtk::Action> m_rename_notebook_action;
   RecentSearchColumnTypes m_find_combo_columns;
   Gtk::ScrolledWindow m_matches_window;
   Gtk::Grid *m_no_matches_box;
@@ -172,6 +177,8 @@ private:
   Gtk::Menu *m_notebook_list_context_menu;
   bool m_initial_position_restored;
   std::string m_search_text;
+  int m_sort_column_id;
+  Gtk::SortType m_sort_column_order;
 
   static Glib::RefPtr<Gdk::Pixbuf> get_note_icon();
 };
