@@ -46,6 +46,7 @@
 #include "sharp/string.hpp"
 #include "sharp/uri.hpp"
 #include "sharp/datetime.hpp"
+#include "preferences.hpp"
 #include "note.hpp"
 #include "utils.hpp"
 #include "debug.hpp"
@@ -184,10 +185,25 @@ namespace gnote {
     }
 
     std::string get_pretty_print_date(const sharp::DateTime & date, bool show_time)
+    {
+      bool use_12h = false;
+      if(show_time) {
+        use_12h = Preferences::obj().get_schema_settings(
+          Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE)->get_string(
+            Preferences::DESKTOP_GNOME_CLOCK_FORMAT) == "12h";
+      }
+      return get_pretty_print_date(date, show_time, use_12h);
+    }
+
+    std::string get_pretty_print_date(const sharp::DateTime & date, bool show_time, bool use_12h)
     {
       std::string pretty_str;
       sharp::DateTime now = sharp::DateTime::now();
-      std::string short_time = date.to_short_time_string ();
+      std::string short_time = use_12h
+        /* TRANSLATORS: time in 12h format. */
+        ? date.to_string("%l:%M %P")
+        /* TRANSLATORS: time in 24h format. */
+        : date.to_string("%H:%M");
 
       if (date.year() == now.year()) {
         if (date.day_of_year() == now.day_of_year()) {
@@ -203,23 +219,6 @@ namespace gnote {
             str(boost::format(_("Yesterday, %1%")) % short_time) :
             _("Yesterday");
         }
-        else if ((date.day_of_year() < now.day_of_year())
-                  && (date.day_of_year() > now.day_of_year() - 6)) {
-          int num_days = now.day_of_year() - date.day_of_year();
-          const char * fmt;
-          if(show_time) {
-            /* TRANSLATORS: 2 or more days ago, up to one week.
-               First argument is number of days, second is time. */
-            fmt = ngettext("%1% day ago, %2%", "%1% days ago, %2%", num_days);
-            pretty_str = str(boost::format(fmt) % num_days % short_time);
-          }
-          else {
-            /* TRANSLATORS: 2 or more days ago, up to one week.
-               Argument is number of days. */
-            fmt = ngettext("%1% day ago", "%1% days ago", num_days);
-            pretty_str = str(boost::format(fmt) % num_days);
-          }
-        }
         else if (date.day_of_year() > now.day_of_year()
                  && date.day_of_year() == now.day_of_year() + 1) {
           pretty_str = show_time ?
@@ -227,36 +226,25 @@ namespace gnote {
             str(boost::format(_("Tomorrow, %1%")) % short_time) :
             _("Tomorrow");
         }
-        else if (date.day_of_year() > now.day_of_year()
-                 && date.day_of_year() < now.day_of_year() + 6) {
-          int num_days = date.day_of_year() - now.day_of_year();
-          const char * fmt;
-          if(show_time) {
-            /* TRANSLATORS: In 2 or more days, up to one week.
-               First argument is number of days, second is time. */
-            fmt = ngettext("In %1% day, %2%", "In %1% days, %2%", num_days);
-            pretty_str = str(boost::format(fmt) % num_days % short_time); 
-          }
-          else {
-            /* TRANSLATORS: In 2 or more days, up to one week.
-               Argument is number of days. */
-            fmt = ngettext("In %1% day", "In %1% days", num_days);
-            pretty_str = str(boost::format(fmt) % num_days);
-          }
-        }
         else {
-          pretty_str = show_time ?
-            date.to_string ("%B %d, %H:%M %p") : // "MMMM d, h:mm tt"
-            date.to_string ("%B %d");            // "MMMM d"
+          /* TRANSLATORS: date in current year. */
+          pretty_str = date.to_string(_("%b %d")); // "MMMM d"
+          if(show_time) {
+            /* TRANSLATORS: first argument is date, second is time. */
+            pretty_str = str(boost::format(_("%1%, %2%")) % pretty_str % short_time);
+          }
         }
       } 
       else if (!date.is_valid()) {
         pretty_str = _("No Date");
       }
       else {
-        pretty_str = show_time ?
-          date.to_string ("%B %d %Y, %H:%M %p") : // "MMMM d yyyy, h:mm tt"
-          date.to_string ("%B %d %Y");            // "MMMM d yyyy"
+        /* TRANSLATORS: date in other than current year. */
+        pretty_str = date.to_string(_("%b %d %Y")); // "MMMM d yyyy"
+        if(show_time) {
+          /* TRANSLATORS: first argument is date, second is time. */
+          pretty_str = str(boost::format(_("%1%, %2%")) % pretty_str % short_time);
+        }
       }
 
       return pretty_str;
@@ -304,6 +292,7 @@ namespace gnote {
                                        const Glib::ustring & msg)
       : Gtk::Dialog()
       , m_extra_widget(NULL)
+      , m_image(NULL)
     {
       set_border_width(5);
       set_resizable(false);
@@ -340,7 +329,6 @@ namespace gnote {
                                   Gtk::ICON_SIZE_DIALOG);
         break;
       default:
-        m_image = new Gtk::Image ();
         break;
       }
 
@@ -370,13 +358,15 @@ namespace gnote {
       label->show();
       label_vbox->attach(*label, 0, label_vbox_row++, 1, 1);
 
-      label = manage(new Gtk::Label(msg));
-      label->set_use_markup(true);
-      label->set_justify(Gtk::JUSTIFY_LEFT);
-      label->set_line_wrap(true);
-      label->set_alignment (0.0f, 0.5f);
-      label->show();
-      label_vbox->attach(*label, 0, label_vbox_row++, 1, 1);
+      if(msg != "") {
+        label = manage(new Gtk::Label(msg));
+        label->set_use_markup(true);
+        label->set_justify(Gtk::JUSTIFY_LEFT);
+        label->set_line_wrap(true);
+        label->set_alignment (0.0f, 0.5f);
+        label->show();
+        label_vbox->attach(*label, 0, label_vbox_row++, 1, 1);
+      }
       
       m_extra_widget_vbox = manage(new Gtk::Grid);
       m_extra_widget_vbox->show();
