@@ -38,6 +38,7 @@ extern "C" {
 #include <gtkmm/textiter.h>
 #include <gtkmm/texttag.h>
 
+#include "base/macros.hpp"
 #include "noteaddin.hpp"
 #include "triehit.hpp"
 #include "utils.hpp"
@@ -54,9 +55,9 @@ namespace gnote {
   public:
     static NoteAddin * create();
     ~NoteRenameWatcher();
-    virtual void initialize ();
-    virtual void shutdown ();
-    virtual void on_note_opened ();
+    virtual void initialize() override;
+    virtual void shutdown() override;
+    virtual void on_note_opened() override;
 
   protected:
     NoteRenameWatcher()
@@ -89,9 +90,9 @@ namespace gnote {
   {
   public:
     static NoteAddin * create();    
-    virtual void initialize ();
-    virtual void shutdown ();
-    virtual void on_note_opened ();
+    virtual void initialize() override;
+    virtual void shutdown() override;
+    virtual void on_note_opened() override;
 
     static bool gtk_spell_available()
       { return true; }
@@ -115,10 +116,10 @@ namespace gnote {
   {
   public:
     static NoteAddin * create();    
-    virtual void initialize ();
-    virtual void shutdown ()
+    virtual void initialize() override;
+    virtual void shutdown() override
       {}
-    virtual void on_note_opened ()
+    virtual void on_note_opened() override
       {}
 
     static bool gtk_spell_available()
@@ -132,15 +133,15 @@ namespace gnote {
   {
   public:
     static NoteAddin * create();    
-    virtual void initialize ();
-    virtual void shutdown ();
-    virtual void on_note_opened ();
+    virtual void initialize() override;
+    virtual void shutdown() override;
+    virtual void on_note_opened() override;
 
   protected:
     NoteUrlWatcher();
   private:
     std::string get_url(const Gtk::TextIter & start, const Gtk::TextIter & end);
-    bool on_url_tag_activated(const NoteTag::Ptr &, const NoteEditor &,
+    bool on_url_tag_activated(const NoteEditor &,
                               const Gtk::TextIter &, const Gtk::TextIter &);
     void apply_url_to_block (Gtk::TextIter start, Gtk::TextIter end);
     void on_apply_tag(const Glib::RefPtr<Gtk::TextBuffer::Tag> & tag,
@@ -166,9 +167,9 @@ namespace gnote {
   {
   public:
     static NoteAddin * create();    
-    virtual void initialize ();
-    virtual void shutdown ();
-    virtual void on_note_opened ();
+    virtual void initialize() override;
+    virtual void shutdown() override;
+    virtual void on_note_opened() override;
 
   private:
     bool contains_text(const std::string & text);
@@ -186,10 +187,9 @@ namespace gnote {
                       const Gtk::TextIter & start, const Gtk::TextIter &end);
 
     bool open_or_create_link(const NoteEditor &, const Gtk::TextIter &,const Gtk::TextIter &);
-    bool on_link_tag_activated(const NoteTag::Ptr &, const NoteEditor &,
+    bool on_link_tag_activated(const NoteEditor &,
                                const Gtk::TextIter &, const Gtk::TextIter &);
 
-    NoteTag::Ptr m_url_tag;
     NoteTag::Ptr m_link_tag;
     NoteTag::Ptr m_broken_link_tag;
 
@@ -205,9 +205,9 @@ namespace gnote {
   {
   public:
     static NoteAddin * create();    
-    virtual void initialize ();
-    virtual void shutdown ();
-    virtual void on_note_opened ();
+    virtual void initialize() override;
+    virtual void shutdown() override;
+    virtual void on_note_opened() override;
 
   protected:
     NoteWikiWatcher()
@@ -234,9 +234,9 @@ namespace gnote {
   {
   public:
     static NoteAddin * create();    
-    virtual void initialize ();
-    virtual void shutdown ();
-    virtual void on_note_opened ();
+    virtual void initialize() override;
+    virtual void shutdown() override;
+    virtual void on_note_opened() override;
 
   protected:
     MouseHandWatcher()
@@ -262,9 +262,9 @@ namespace gnote {
   {
   public:
     static NoteAddin * create();
-    virtual void initialize ();
-    virtual void shutdown ();
-    virtual void on_note_opened ();
+    virtual void initialize() override;
+    virtual void shutdown() override;
+    virtual void on_note_opened() override;
 
   private:
     void on_tag_added(const Note&, const Tag::Ptr&);
